@@ -462,6 +462,9 @@ def compare(*args, **kw):
                       be added to the global comparer registry for the duration
                       of this call.
     """
+
+    __tracebackhide__ = True
+
     prefix = kw.pop('prefix', None)
     suffix = kw.pop('suffix', None)
     raises = kw.pop('raises', True)
@@ -545,8 +548,6 @@ class Comparison(object):
         if isinstance(other, BaseException):
             v = dict(vars(other))
             v['args'] = other.args
-            if PY3 and '_not_found' in v:
-                del v['_not_found']
         else:
             try:
                 v = vars(other)
